@@ -4,6 +4,18 @@
 
 namespace glmnetpp {
 
+template <class ElnetPointDerived>
+struct ElnetPointCRTPBase;
+template <class ElnetPointDerived>
+struct ElnetPointNonLinearCRTPBase;
+
+template <class Derived>
+struct ElnetPointBinomialBase;
+template <class Derived>
+struct ElnetPointGaussianBase;
+template <class Derived>
+struct ElnetPointPoissonBase; 
+
 template <util::glm_type glm
         , util::mode_type<glm> mode
         , class ElnetPointInternalPolicy=ElnetPointInternal<glm, mode> >
@@ -14,4 +26,5 @@ template <util::glm_type glm
         , class SpElnetPointInternalPolicy=SpElnetPointInternal<glm, mode> >
 struct SpElnetPoint;
 
+
 } // namespace glmnetpp
